#include "example.h"

static void usage( char *pgmName );

#define OPT_ARG_LIST        "hd:i:j:r:m:s:"

/********************************************************
**
** Test Module: SetTime.c
**
** Purpose:     Set the current time on the board
**
**
*********************************************************/

int main (int argc, char *argv[])
{
    TPRO_BoardObj   *hnd = NULL;
    TPRO_TimeObj    timeInfo;
    int             rc;
    int             ret = 0;
    int             devIdx = DEFAULT_DEV_NUM;
    char            *devName = DEFAULT_DEV;
    int             optRc;
    char            fullDevName[MAX_DEVICE_PATH_LENGTH];
    char            *errMsg;
    char            *pgmname = argv[0];

    /*
     * initialize some default values.
     */
    timeInfo.days = 256;
    timeInfo.hours = 12;
    timeInfo.minutes = 30;
    timeInfo.seconds = 30;

    opterr = 0;
    while ( (optRc = getopt (argc, argv, OPT_ARG_LIST)) != -1 )
    {
        switch ( optRc )
        {
            case 'd' :
                devName = optarg;
                break;
            case 'i' :
                devIdx = atoi(optarg);
                break;
            case 'j' :
                timeInfo.days = atoi(optarg);
                break;
            case 'r' :
                timeInfo.hours = atoi(optarg);
                break;
            case 'm' :
                timeInfo.minutes = atoi(optarg);
                break;
            case 's' :
                timeInfo.seconds = atoi(optarg);
                break;
            case 'h' :
            default:
                usage( pgmname );
                return (1);
        }
    }

    /*
     * If leftover args, then command is misunderstood...
     * so let user know.
     */
    if ( optind != argc )
    {
        usage( pgmname );
        return (1);
    }

    /*
     * construct the device name
     */
    (void)sprintf_s( fullDevName, MAX_DEVICE_PATH_LENGTH, "%s%s%d", DEVICE_ROOT, devName, devIdx );

    /*
     * open the device
     */
    if ( (rc = TPRO_open(&hnd, fullDevName)) != TPRO_SUCCESS )
    {
        /* 
         * if errors, close it
         */
        printf("%s: Could not open <%s> : rc <%d>\n", 
                        pgmname, fullDevName, rc);
        return (1);
    }



    /*
     * set the current time
     */
    int done = 0;
    while ( !done )
    {
        if ( (rc = TPRO_setTime(hnd, &timeInfo)) != TPRO_SUCCESS )
        {
            done = 1;

            switch (rc)
            {
                case TPRO_DAY_PARM_ERR:
                    errMsg = "TPRO_DAY_PARM_ERR";
                    break;
                case TPRO_HOUR_PARM_ERR:
                    errMsg = "TPRO_HOUR_PARM_ERR";
                    break;
                case TPRO_MIN_PARM_ERR:
                    errMsg = "TPRO_MIN_PARM_ERR";
                    break;
                case TPRO_SEC_PARM_ERR:
                    errMsg = "TPRO_SEC_PARM_ERR";
                    break;
                case TPRO_INVALID_BOARD_TYPE_ERR:
                    errMsg = "TPRO_INVALID_BOARD_TYPE_ERR";
                    break;
                case TPRO_DEV_BUSY:
                    errMsg = "TPRO_DEV_BUSY waiting...";
                    done = 0;
                    break;
                case TPRO_HANDLE_ERR:
                    errMsg = "TPRO_HANDLE_ERR";
                    break;
                case TPRO_COMM_ERR:
                    errMsg = "TPRO_COMM_ERR";
                    break;
                default:
                    errMsg = "Unknown error";
                break;
            }

            (void) printf("%s: <%s> %s rc: <%d>.\n", 
                    pgmname, fullDevName, errMsg, rc);

            ret = 1;
        }
        else
        {
            /*
             * success:  confirm time set 
             */
            (void)printf("<%s> %s: Day <%d> Hours <%d> Min <%d> Sec <%d>\n",
                        fullDevName, pgmname, timeInfo.days, 
                        timeInfo.hours, timeInfo.minutes, timeInfo.seconds);

            done = 1;
            ret = 0;
        }

    } /* end while !done */

    /*
     * close the handle to the board
     */
    if ( (rc = TPRO_close(hnd)) != TPRO_SUCCESS )
    {
        (void) printf("%s: error closing <%s> rc: <%d>\n", 
                pgmname, fullDevName, rc );
        ret = 1;
    }

    return (ret);
}

void usage( char *pgmName )
{
    (void)printf("Usage: %s [-j DAY] [-r hour] [-m MINUTE] \n", pgmName);
    (void)printf("\t\t[-s SECONDS] [-h] [-d NAME] [-i INDEX] \n\n" );
    (void)printf("\t-j   day (0-366)\n");
    (void)printf("\t-r   hour (0-23)\n");
    (void)printf("\t-m   minute (0-59)\n");
    (void)printf("\t-s   seconds (0-59)\n");
    (void)printf("\t-h   help message\n");
    (void)printf("\t-d   device name (e.g. %s)\n", DEFAULT_DEV);
    (void)printf("\t-i   device index (e.g. 0,1,..)\n");
    (void)printf("\t\tsuch that combined forms: %s0\n\n", DEFAULT_DEV);
}




    
